<?php

if ( function_exists('register_sidebar') )
{
	register_sidebar(array(
		'name' => 'sidebar-1',
		'before_widget' => '<div class="section widget %2$s" id="%1$s">',
		'after_widget' => '</div>',
		'before_title' => '<div class="section-title">',
		'after_title' => '</div>',
	));

	register_sidebar(array(
		'name' => 'sidebar-2',
		'before_widget' => '<div class="section widget %2$s" id="%1$s">',
		'after_widget' => '</div>',
		'before_title' => '<div class="section-title">',
		'after_title' => '</div>',
	));
}

function sm_env($key) {
	if ($key == 'HTTPS') {
		if (isset($_SERVER) && !empty($_SERVER)) {
			return (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on');
		}
		return (strpos(env('SCRIPT_URI'), 'https://') === 0);
	}

	if ($key == 'SCRIPT_NAME') {
		if (env('CGI_MODE') && isset($_ENV['SCRIPT_URL'])) {
			$key = 'SCRIPT_URL';
		}
	}

	$val = null;
	if (isset($_SERVER[$key])) {
		$val = $_SERVER[$key];
	} elseif (isset($_ENV[$key])) {
		$val = $_ENV[$key];
	} elseif (getenv($key) !== false) {
		$val = getenv($key);
	}

	if ($key == 'REMOTE_ADDR' && $val == env('SERVER_ADDR')) {
		$addr = env('HTTP_PC_REMOTE_ADDR');
		if ($addr != null) {
			$val = $addr;
		}
	}

	if ($val !== null) {
		return $val;
	}

	switch ($key) {
		case 'SCRIPT_FILENAME':
			if (defined('SERVER_IIS') && SERVER_IIS === true){
				return str_replace('\\\\', '\\', env('PATH_TRANSLATED') );
			}
		break;
		case 'DOCUMENT_ROOT':
			$offset = 0;
			if (!strpos(env('SCRIPT_NAME'), '.php')) {
				$offset = 4;
			}
			return substr(env('SCRIPT_FILENAME'), 0, strlen(env('SCRIPT_FILENAME')) - (strlen(env('SCRIPT_NAME')) + $offset));
		break;
		case 'PHP_SELF':
			return r(env('DOCUMENT_ROOT'), '', env('SCRIPT_FILENAME'));
		break;
		case 'CGI_MODE':
			return (PHP_SAPI == 'cgi');
		break;
		case 'HTTP_BASE':
			$host = env('HTTP_HOST');
			if (substr_count($host, '.') != 1) {
				return preg_replace ('/^([^.])*/i', null, env('HTTP_HOST'));
			}
		return '.' . $host;
		break;
	}
	return null;
}

function sm_mainnav($args=array())
{
	$defaults = array(
		'depth'        => 1,
		'title_li'     => '',
		'sort_column'  => 'menu_order, post_title',
	);

	$args = array_merge($defaults, $args);

	if ( is_home() ){
		$home_link = '<li class="current_page_item"><a href="' . get_bloginfo('url') . '">' . __('Home') . '</a></li>';
	}
	else {
		$home_link = '<li><a href="' . get_bloginfo('url') . '">' . __('Home') . '</a></li>';
	}

	echo $home_link;
	wp_list_pages($args);
}

function sm_subnav()
{
	global $post, $wpdb;
	
	if ( is_page() )
	{
		$child_of = null;

		if ( $wpdb->get_var("SELECT COUNT(*) FROM $wpdb->posts WHERE post_type='page' && post_parent = ".$post->ID) > 0 ){
			$child_of = $post->ID;
		}
		else if ( $post->post_parent != 0 ){
			$child_of = $post->post_parent;
		}

		if ( !is_null($child_of) )
		{
			echo '<div id="sub-nav">' . "\n";
				echo '<ul class="tabbed">' . "\n";
					wp_list_pages('title_li=&child_of='.$child_of);
				echo '</ul>' . "\n";
				echo '<div class="clearer">&nbsp;</div>' . "\n";
			echo '</div>' . "\n";	
		}
	}
}




/*
	Comment author name fix
----------------------------------------------------------------- */

function sm_str_cut($str, $maxlen, $after='..'){
	return ( strlen($str) > $maxlen ) ? substr($str, 0, $maxlen-strlen($after)) . $after : $str;
}

function sm_comment_author_link($str){
	return sm_str_cut($str, 18);
}
add_filter('get_comment_author', 'sm_comment_author_link');


/*
	List comments
----------------------------------------------------------------- */
function sm_comment($comment, $args, $depth)
{
	$GLOBALS['comment'] = $comment;
	
	if ( $depth == 1 ) : ?>
	<li class="comment <?php if ( $args['has_children'] ) : ?>comment-parent<?php else : ?>comment-single<?php endif; ?>" id="comment-<?php comment_ID(); ?>">

		<div class="comment-profile-wrapper left">

			<div class="comment-profile">				
				<div class="comment-gravatar"><?php echo get_avatar($comment,40); ?></div>
				<div class="comment-author"><?php comment_author_link() ?></div>
			</div>

		</div>

		<div class="comment-content-wrapper right">
			<div class="comment-content-wrapper-2">

				<div class="comment-body">
				
					<div class="comment-arrow"></div>
					
					<div class="post-date">
						<div class="left"><?php comment_date('F jS, Y') ?> at <?php comment_time() ?><?php if ( $depth < $args['max_depth'] ) : ?> <span class="text-separator">|</span> <?php comment_reply_link(array_merge($args, array('reply_text' => 'Reply &#187;', 'depth' => $depth, 'max_depth' => $args['max_depth']))); ?><?php endif; ?></div>
						<div class="right"><?php edit_comment_link('Edit', '', ' <span class="text-separator">|</span> '); ?><a href="#comment-<?php comment_ID() ?>" title="Permanent link to this reply">#<?php comment_ID() ?></a></div>
						<div class="clearer">&nbsp;</div>
					</div>

					<div class="comment-text">
<?php if ( $comment->comment_approved == '0' ) : ?>
					<p><em>Your comment is awaiting moderation.</em></p>
<?php endif; ?>
						<?php comment_text(); ?>			
						<div class="clearer">&nbsp;</div>
					</div>					

					<div class="clearer">&nbsp;</div>

				</div>
			
			</div>
		</div>

		<div class="clearer">&nbsp;</div>

	<?php else : ?>

	<li class="comment" id="comment-<?php comment_ID(); ?>">
		
		<div class="comment-content">

			<div class="comment-body">
			
				<div class="post-date">
					<div class="left"><?php echo get_avatar($comment, 14); ?> <span class="loud"><?php comment_author_link() ?></span> - <?php comment_date('F jS, Y') ?> at <?php comment_time() ?><?php if ( $depth < $args['max_depth'] ) : ?> <span class="text-separator">|</span> <?php comment_reply_link(array_merge($args, array('reply_text' => 'Reply &#187;', 'depth' => $depth, 'max_depth' => $args['max_depth']))); ?><?php endif; ?></div>
					<div class="right"><?php edit_comment_link('Edit', '', ' <span class="text-separator">|</span> '); ?><a href="#comment-<?php comment_ID() ?>" title="Permanent link to this reply">#<?php comment_ID() ?></a></div>
					<div class="clearer">&nbsp;</div>
				</div>

	<?php if ( $comment->comment_approved == '0' ) : ?>
				<p><em>Your comment is awaiting moderation.</em></p>
	<?php endif; ?>

				<div class="comment-text">
					<?php comment_text(); ?>					
					<div class="clearer">&nbsp;</div>
				</div>

			</div>				

		</div>
		
	<?php endif; ?>
<?php
}


/*
	Page navigation
----------------------------------------------------------------- */

function sm_page_navigation($object_type)
{
	global $wp_query, $post, $paged;

	$page_numbers = false;

	$defaults['end_size'] = 2;
	$defaults['prev_next'] = 0;
	$defaults['mid_size'] = 2;

	if ( $object_type == 'comments' )
	{
		$next = get_next_comments_link();
		$prev = get_previous_comments_link();
		$page_numbers = paginate_comments_links(array('prev_next'=>$defaults['prev_next'], 'end_size'=>$defaults['end_size'], 'mid_size'=>$defaults['mid_size'], 'echo'=>0));
	}
	else if ( $object_type == 'archive' )
	{
		$next = get_next_posts_link();
		$prev = get_previous_posts_link();
		
		if ( get_option('permalink_structure') == "" )
		{
			$uri = sm_env('REQUEST_URI');
			$base = preg_replace('/paged=\d+/i', '', $uri) . '%_%';
			$pre = ( strpos($uri, '&paged=') === false ) ? '&' : '';

			$format = $pre.'paged=%#%';
		}
		else 
		{
			$base = user_trailingslashit(preg_replace('%page/\d+/%i', '', sm_env('SCRIPT_URL')), 'paged') . '%_%';
			$format = 'page/%#%/';			
		}

		$links = paginate_links(array('prev_next'=>0, 'end_size'=>$defaults['end_size'], 'mid_size'=>$defaults['mid_size'], 'echo'=>0, 'type'=>'array', 'total'=>$wp_query->max_num_pages, 'current'=>$paged, 'base'=>$base, 'format'=>$format));

		if ( $links )
			$page_numbers = join('', $links);
	}

	if ( $next || $prev ) {
		if ( !$next ) $next = '&nbsp;';
		if ( !$prev ) $prev = '&nbsp;';
	?>
	<div class="navigation navigation-<?php echo $object_type; ?>">

		<div class="left"><?php echo $prev; ?>&nbsp;</div>
		<div class="right">&nbsp;<?php echo $next; ?></div>

	<?php if ( true || $page_numbers ) : ?>
		<div class="text-center">Page: <?php echo $page_numbers; ?></div>
	<?php endif; ?>

		<div class="clearer">&nbsp;</div>

	</div>
	<?php
	}
}


?>